@@ -1,6 +1,4 @@
-import logging
 import pathlib
-import time
 from functools import partial
 
 import typer
@@ -27,7 +25,7 @@ app.add_typer(flowmaster.cli.item.app, name="item")
 def init():
     from flowmaster.models import database, FlowItem
 
-    typer.echo(f"APP_HOME={APP_HOME}")
+    typer.echo(f"\nAPP_HOME={APP_HOME}")
 
     pathlib.Path.mkdir(APP_HOME, exist_ok=True)
     pathlib.Path.mkdir(FILE_STORAGE_DIR, exist_ok=True)
@@ -53,30 +51,18 @@ def prepare_for_run(dry_run: bool = False):
     FlowItem.clear_statuses_of_lost_items()
 
     if dry_run:
-        FlowItem.delete().where(FlowItem.name == "fakedata.etl.flow.yml").execute()
+        FlowItem.delete().where("fakedata.etl.flow" in FlowItem.name).execute()
 
 
 @app.command()
 def run(interval: int = 20, dry_run: bool = False):
     prepare_for_run(dry_run=dry_run)
 
-    from flowmaster.utils.logging_helper import CreateLogger
-    from flowmaster.operators.base.work import order_flow
+    from flowmaster.utils.local_executor import start_executor
 
-    logger = CreateLogger("local_executor", "local_executor.log", level=logging.INFO)
-    begin = time.time()
-    duration = interval
+    typer.echo("Executor: Local\n")
 
-    while True:
-        logger.info("Ordering flow")
-        list(order_flow(logger=logger, async_mode=False, dry_run=dry_run))
-
-        if duration >= interval:
-            duration = 0
-            begin = time.time()
-        else:
-            time.sleep(interval - duration)
-            duration += time.time() - begin
+    start_executor(interval=interval, dry_run=dry_run)
 
 
 @app.command()
@@ -86,6 +72,8 @@ def run_thread(workers: int = 2, interval: int = 20, dry_run: bool = False):
     from flowmaster.operators.base.work import order_flow
     from flowmaster.utils.thread_executor import ThreadExecutor
 
+    typer.echo("Executor: Threading\n")
+
     order_task_func = partial(order_flow, dry_run=dry_run, async_mode=True)
     executor = ThreadExecutor(order_task_func=order_task_func)
     executor.start(order_interval=interval, workers=workers)
