@@ -1,6 +1,6 @@
 import datetime as dt
 from logging import Logger, getLogger
-from typing import Iterator, Optional, Union, TYPE_CHECKING
+from typing import Iterator, Optional, TYPE_CHECKING
 
 import pendulum
 
@@ -9,7 +9,6 @@ from flowmaster.utils import iter_range_datetime, iter_period_from_range
 
 if TYPE_CHECKING:
     from flowmaster.operators.base.policy import BaseFlowConfig
-    from flowmaster.operators.etl.service import ETLOperator
 
 
 class Work:
@@ -99,7 +98,7 @@ class Work:
 
 def order_flow(
     *, logger: Logger, async_mode: bool = False, dry_run: bool = False, **kwargs
-) -> Union[Iterator["ETLOperator"]]:
+) -> Iterator:
     from flowmaster.operators.etl.work import order_etl_flow
 
     yield from order_etl_flow(
