@@ -1,7 +1,9 @@
 import importlib
 
 from flowmaster.operators.etl.providers.abstract import ProviderAbstract
+from flowmaster.operators.etl.providers.csv import CSVProvider
 from flowmaster.operators.etl.providers.fakedata import FakeDataProvider
+from flowmaster.operators.etl.providers.sqlite import SQLiteProvider
 from flowmaster.operators.etl.providers.yandex_direct import YandexDirectProvider
 from flowmaster.operators.etl.providers.yandex_metrika_logs import (
     YandexMetrikaLogsProvider,
@@ -20,7 +22,9 @@ provider_classes = {
     YandexMetrikaStatsProvider.name: YandexMetrikaStatsProvider,
     YandexMetrikaManagementProvider.name: YandexMetrikaManagementProvider,
     YandexMetrikaLogsProvider.name: YandexMetrikaLogsProvider,
-    YandexDirectProvider.name: YandexDirectProvider
+    YandexDirectProvider.name: YandexDirectProvider,
+    CSVProvider.name: CSVProvider,
+    SQLiteProvider.name: SQLiteProvider,
 }
 
 # Fetching custom providers.
