@@ -72,7 +72,7 @@ class ETLWork(Work):
 @catch_exceptions
 def order_etl_flow(
     *, logger: Logger, async_mode: bool = False, dry_run: bool = False
-) -> Iterator["ETLOperator"]:
+) -> Iterator:
     """Prepare flow function to be sent to the queue and executed"""
     from flowmaster.operators.etl.service import ETLOperator
     from flowmaster.operators.etl.policy import ETLFlowConfig
