@@ -1,18 +1,18 @@
 from flowmaster.operators.etl.loaders.clickhouse.policy import ClickhouseLoadPolicy
 from flowmaster.operators.etl.loaders.clickhouse.policy import ClickhouseTransformPolicy
-from flowmaster.operators.etl.loaders.clickhouse.service import ClickhouseLoad
-from flowmaster.operators.etl.loaders.file.service import FileLoad
+from flowmaster.operators.etl.loaders.clickhouse.service import ClickhouseLoader
+from flowmaster.operators.etl.loaders.csv.service import CSVLoader
 from flowmaster.operators.etl.policy import ETLFlowConfig
 from flowmaster.operators.etl.providers import YandexDirectProvider
 from flowmaster.operators.etl.providers.yandex_direct.policy import (
     YandexDirectExportPolicy as ExportPolicy,
 )
-from tests.fixtures import work_policy, file_load_policy, file_transform_policy
+from tests.fixtures import work_policy, csv_load_policy, csv_transform_policy
 
-ya_direct_report_to_file_config = ETLFlowConfig(
-    name="ya_direct_report_to_file",
+ya_direct_report_to_csv_config = ETLFlowConfig(
+    name="ya_direct_report_to_csv",
     provider=YandexDirectProvider.name,
-    storage=FileLoad.name,
+    storage=CSVLoader.name,
     work=work_policy,
     export=ExportPolicy(
         credentials=ExportPolicy.CredentialsPolicy(access_token="token"),
@@ -30,16 +30,16 @@ ya_direct_report_to_file_config = ETLFlowConfig(
             ),
         ),
     ),
-    transform=file_transform_policy,
-    load=file_load_policy,
+    transform=csv_transform_policy,
+    load=csv_load_policy,
 )
 
 ya_direct_report_to_clickhouse_config = ETLFlowConfig(
     **{
-        **ya_direct_report_to_file_config.dict(),
+        **ya_direct_report_to_csv_config.dict(),
         **dict(
             name="ya_direct_report_to_clickhouse_config",
-            storage=ClickhouseLoad.name,
+            storage=ClickhouseLoader.name,
             transform=ClickhouseTransformPolicy(
                 error_policy="default",
                 column_map={"CampaignType": "CampaignType", "Cost": "Cost"},
@@ -54,7 +54,7 @@ ya_direct_report_to_clickhouse_config = ETLFlowConfig(
                     columns=["CampaignType String", "Cost Float32"],
                     orders=["CampaignType"],
                 ),
-                data_cleaning_mode=ClickhouseLoad.DataCleaningMode.truncate,
+                data_cleaning_mode=ClickhouseLoader.DataCleaningMode.truncate,
                 sql_before=["SELECT 1"],
                 sql_after=["SELECT 2"],
             ),
@@ -62,11 +62,11 @@ ya_direct_report_to_clickhouse_config = ETLFlowConfig(
     }
 )
 
-ya_direct_campaigns_to_file_config = ETLFlowConfig(
+ya_direct_campaigns_to_csv_config = ETLFlowConfig(
     **{
-        **ya_direct_report_to_file_config.dict(),
+        **ya_direct_report_to_csv_config.dict(),
         **dict(
-            name="ya_direct_campaigns_to_file_config",
+            name="ya_direct_campaigns_to_csv",
             export=ExportPolicy(
                 credentials=ExportPolicy.CredentialsPolicy(access_token="token"),
                 resource="campaigns",
@@ -86,10 +86,10 @@ ya_direct_campaigns_to_file_config = ETLFlowConfig(
 
 ya_direct_campaigns_to_clickhouse_config = ETLFlowConfig(
     **{
-        **ya_direct_campaigns_to_file_config.dict(),
+        **ya_direct_campaigns_to_csv_config.dict(),
         **dict(
-            name="ya_direct_campaigns_to_clickhouse_config",
-            storage=ClickhouseLoad.name,
+            name="ya_direct_campaigns_to_clickhouse",
+            storage=ClickhouseLoader.name,
             transform=ClickhouseTransformPolicy(
                 error_policy="default",
                 column_map={"Id": "CampaignID", "Name": "CampaignName"},
@@ -104,7 +104,7 @@ ya_direct_campaigns_to_clickhouse_config = ETLFlowConfig(
                     columns=["CampaignName String", "CampaignID UInt64"],
                     orders=["CampaignID"],
                 ),
-                data_cleaning_mode=ClickhouseLoad.DataCleaningMode.truncate,
+                data_cleaning_mode=ClickhouseLoader.DataCleaningMode.truncate,
                 sql_before=["SELECT 1"],
                 sql_after=["SELECT 2"],
             ),
