@@ -7,7 +7,7 @@ from flowmaster.operators.etl.service import ETLOperator
 from flowmaster.utils.thread_executor import catch_exceptions, ThreadExecutor
 from flowmaster.utils.yaml_helper import YamlHelper
 from tests import get_tests_dir
-from tests.fixtures.yandex_metrika import yml_visits_to_file_config as CONFIG
+from tests.fixtures.yandex_metrika import yml_visits_to_csv_config as CONFIG
 
 credentials = YamlHelper.parse_file(get_tests_dir("tests2") / "credentials.yml")
 CONFIG.export.credentials = YandexMetrikaLogsExportPolicy.CredentialsPolicy(
